==> eagle-i-ui-gwt-1.0-MS6.0-sources.jar: org/eaglei/ui/gwt/FooterPanel.java <==
package org.eaglei.ui.gwt;

import org.eaglei.model.gwt.rpc.ClientModelManager;
import org.eaglei.model.gwt.rpc.ClientModelManager.VersionCallback;

import com.google.gwt.core.client.GWT;
import com.google.gwt.uibinder.client.UiBinder;
import com.google.gwt.uibinder.client.UiField;
import com.google.gwt.user.client.Command;
import com.google.gwt.user.client.DeferredCommand;
import com.google.gwt.user.client.ui.Composite;
import com.google.gwt.user.client.ui.Label;
import com.google.gwt.user.client.ui.Widget;

public class FooterPanel extends Composite {

    interface Binder extends UiBinder<Widget, FooterPanel> {
    }

    private static final Binder binder = GWT.create(Binder.class);

    @UiField
    Label appVersionLabel;
    @UiField
    Label ontVersionLabel;
    
    public FooterPanel() {
        this("");
    }
    
    public FooterPanel(String version) {
        initWidget(binder.createAndBindUi(this));
        appVersionLabel.setText(appVersionLabel.getText() + version);
        DeferredCommand.addCommand(new Command() {

            @Override
            public void execute() {
                ClientModelManager.INSTANCE.getVersion(new VersionCallback() {

                    @Override
                    public void onSuccess(String result) {
                        if (result != null) {
                            ontVersionLabel.setText(ontVersionLabel.getText() + result);
                        }
                    }
                    
                });
            }
            
        });
    }
   
}

==> eagle-i-ui-gwt-1.2-MS2.01-sources.jar: org/eaglei/ui/gwt/FooterPanel.java <==
package org.eaglei.ui.gwt;

import org.eaglei.model.gwt.rpc.ClientModelManager;
import org.eaglei.model.gwt.rpc.ModelService;
import org.eaglei.model.gwt.rpc.ModelServiceAsync;
import org.eaglei.model.gwt.rpc.ClientModelManager.VersionCallback;

import com.google.gwt.core.client.GWT;
import com.google.gwt.uibinder.client.UiBinder;
import com.google.gwt.uibinder.client.UiField;
import com.google.gwt.user.client.Command;
import com.google.gwt.user.client.DeferredCommand;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.rpc.AsyncCallback;
import com.google.gwt.user.client.ui.Composite;
import com.google.gwt.user.client.ui.Label;
import com.google.gwt.user.client.ui.Widget;

public class FooterPanel extends Composite {

    interface Binder extends UiBinder<Widget, FooterPanel> {
    }

    private static final Binder binder = GWT.create(Binder.class);

    @UiField
    Label appVersionLabel;
    @UiField
    Label ontVersionLabel;
    
    public FooterPanel() {
        this("");
    }
    
    public FooterPanel(String version) {
        initWidget(binder.createAndBindUi(this));
        appVersionLabel.setText(appVersionLabel.getText() + version);
        DeferredCommand.addCommand(new Command() {

            @Override
            public void execute() {
                ModelServiceAsync modelService = GWT.create(ModelService.class);
                modelService.getVersion(new AsyncCallback<String>() {

                    @Override
                    public void onFailure(Throwable caught) {
                        //Window.alert("Ontology Version: failure");
                    }

                    @Override
                    public void onSuccess(String result) {
                        if (result != null) {
                            ontVersionLabel.setText(ontVersionLabel.getText() + result);
                        }
                    }
                    
                });
            }
            
        });
    }
   
}
